pub struct NodeStyleRule {
pub selector: NodeSelector,
pub style: NodeStyle,
}Expand description
A selector and the style to overlay on matching nodes.
Fields
selector: NodeSelectorPredicate used to select nodes.
style: NodeStyleStyle overlaid on selected nodes.
Implementations
Sourceimpl NodeStyleRule
impl NodeStyleRule
Sourcepub fn new(selector: NodeSelector, style: NodeStyle) -> Self
pub fn new(selector: NodeSelector, style: NodeStyle) -> Self
Creates a style rule from a selector and style.