ExprNode

Enum ExprNode 

pub enum ExprNode {
Show 18 variants RealConst(f64), ComplexConst(Complex64), ScalarParam(Parameter), EventScalar(Arc<str>), EventP4Component { name: Arc<str>, component: P4Component, }, Unary { op: UnaryOp, input: ExprId, }, Binary { op: BinaryOp, lhs: ExprId, rhs: ExprId, }, NaryAdd { terms: Vec<ExprId>, }, NaryMul { factors: Vec<ExprId>, }, Complex { re: ExprId, im: ExprId, }, Vector { elements: Vec<ExprId>, }, Matrix { rows: usize, cols: usize, elements: Vec<ExprId>, }, Component { input: ExprId, index: usize, }, MatrixElement { input: ExprId, row: usize, col: usize, }, MatMul { lhs: ExprId, rhs: ExprId, }, MatVec { matrix: ExprId, vector: ExprId, }, Dot { lhs: ExprId, rhs: ExprId, }, Solve { matrix: ExprId, rhs: ExprId, },
}
Serialized node in a topologically ordered ExprGraph.

Variants



RealConst(f64)

A real constant.



ComplexConst(Complex64)

A complex constant.



ScalarParam(Parameter)

A scalar fit parameter.



EventScalar(Arc<str>)

A named scalar event column.



EventP4Component

One component of a named event four-momentum.

Fields

name: Arc<str>

Event column base name.

component: P4Component

Requested four-momentum component.



Unary

A unary operation.

Fields

op: UnaryOp

Operation to apply.

input: ExprId

Input node.



Binary

A binary operation.

Fields

op: BinaryOp

Operation to apply.

lhs: ExprId

Left operand.

rhs: ExprId

Right operand.



NaryAdd

A sum of zero or more terms.

Fields

terms: Vec<ExprId>

Term nodes.



NaryMul

A product of zero or more factors.

Fields

factors: Vec<ExprId>

Factor nodes.



Complex

A complex scalar assembled from real and imaginary expressions.

Fields

re: ExprId

Real component.

im: ExprId

Imaginary component.



Vector

A vector assembled from scalar elements.

Fields

elements: Vec<ExprId>

Scalar element nodes.



Matrix

A row-major matrix assembled from scalar elements.

Fields

rows: usize

Number of rows.

cols: usize

Number of columns.

elements: Vec<ExprId>

Row-major scalar elements.



Component

A vector component selection.

Fields

input: ExprId

Vector input.

index: usize

Zero-based component index.



MatrixElement

A matrix element selection.

Fields

input: ExprId

Matrix input.

row: usize

Zero-based row index.

col: usize

Zero-based column index.



MatMul

Matrix-matrix multiplication.

Fields

lhs: ExprId

Left matrix.

rhs: ExprId

Right matrix.



MatVec

Matrix-vector multiplication.

Fields

matrix: ExprId

Matrix operand.

vector: ExprId

Vector operand.



Dot

Vector dot product.

Fields

lhs: ExprId

Left vector.

rhs: ExprId

Right vector.



Solve

Solution of a linear system.

Fields

matrix: ExprId

Coefficient matrix.

rhs: ExprId

Right-hand-side vector or matrix.

Implementations

Source

impl ExprNode

pub fn from_folded_const(value: Complex64) -> Self

Creates the most compact constant-node representation for value.

pub fn const_value(&self) -> Option<Complex64>

Returns the node’s scalar constant value, if it is a constant.

pub fn is_zero(node: &ExprNode) -> bool

Returns whether node is the scalar constant zero.

pub fn is_one(node: &ExprNode) -> bool

Returns whether node is the scalar constant one.

pub fn child_ids(&self) -> Vec<ExprId>

Returns the identifiers of this node’s direct dependencies.